@@ -179,6 +179,8 @@ extern int main_debug;
     KW_CHECK_HOSTNAME = 10093,     /* KW_CHECK_HOSTNAME  */
     KW_BAD_HOSTNAME = 10094,       /* KW_BAD_HOSTNAME  */
     KW_LOG_LEVEL = 10095,          /* KW_LOG_LEVEL  */
+    KW_IDLE_TIMEOUT = 10096,       /* KW_IDLE_TIMEOUT  */
+    KW_CHECK_PROGRAM = 10097,      /* KW_CHECK_PROGRAM  */
     KW_KEEP_TIMESTAMP = 10100,     /* KW_KEEP_TIMESTAMP  */
     KW_USE_DNS = 10110,            /* KW_USE_DNS  */
     KW_USE_FQDN = 10111,           /* KW_USE_FQDN  */
@@ -239,6 +241,7 @@ extern int main_debug;
     KW_DEFAULT_SEVERITY = 10301,   /* KW_DEFAULT_SEVERITY  */
     KW_SDATA_PREFIX = 10302,       /* KW_SDATA_PREFIX  */
     KW_PORT = 10323,               /* KW_PORT  */
+    KW_HTTP = 10324,               /* KW_HTTP  */
     KW_USE_TIME_RECVD = 10340,     /* KW_USE_TIME_RECVD  */
     KW_FACILITY = 10350,           /* KW_FACILITY  */
     KW_SEVERITY = 10351,           /* KW_SEVERITY  */
@@ -393,6 +396,8 @@ extern int main_debug;
 #define KW_CHECK_HOSTNAME 10093
 #define KW_BAD_HOSTNAME 10094
 #define KW_LOG_LEVEL 10095
+#define KW_IDLE_TIMEOUT 10096
+#define KW_CHECK_PROGRAM 10097
 #define KW_KEEP_TIMESTAMP 10100
 #define KW_USE_DNS 10110
 #define KW_USE_FQDN 10111
@@ -453,6 +458,7 @@ extern int main_debug;
 #define KW_DEFAULT_SEVERITY 10301
 #define KW_SDATA_PREFIX 10302
 #define KW_PORT 10323
+#define KW_HTTP 10324
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
 #define KW_SEVERITY 10351
